@@ -255,7 +255,7 @@ class ReconJob:
             p_success(f'>>> {target_pdb.nrec_tags(keys=["assim"])} records tagged "assim"')
             p_success(f'>>> {target_pdb.nrec_tags(keys=["eval"])} records tagged "eval"')
 
-    def load_clim(self, tag, path_dict=None, rename_dict=None, anom_period=None, time_name=None, lon_name=None, verbose=False):
+    def load_clim(self, tag, path_dict=None, rename_dict=None, anom_period=None, time_name=None, load=False, lon_name=None, verbose=False):
         ''' Load grided climate data, either model simulations or instrumental observations.
 
         Args:
@@ -265,6 +265,7 @@ class ReconJob:
             rename_dict (dict): the dictionary for renaming the variable names in the climate data files.
             anom_period (tuple or list): the time period for computing the anomaly.
             time_name (str): the name of the time dimension in the climate data files.
+            load (bool): if True, the data will be loaded into the memory instead of lazy-loading.
             lon_name (str): the name of the longitude dimension in the climate data files.
             verbose (bool, optional): print verbose information. Defaults to False.
         '''
@@ -282,12 +283,12 @@ class ReconJob:
                 vn_in_file = rename_dict[vn]
 
             if anom_period == 'null':
-                self.__dict__[tag][vn] = ClimateField().load_nc(path, vn=vn_in_file, time_name=time_name).wrap_lon(lon_name=lon_name, time_name=time_name)
+                self.__dict__[tag][vn] = ClimateField().load_nc(path, vn=vn_in_file, time_name=time_name, load=load).wrap_lon(lon_name=lon_name, time_name=time_name)
             else:
                 if time_name == 'time':
-                    self.__dict__[tag][vn] = ClimateField().load_nc(path, vn=vn_in_file, time_name=time_name).get_anom(ref_period=anom_period).wrap_lon(lon_name=lon_name, time_name=time_name)
+                    self.__dict__[tag][vn] = ClimateField().load_nc(path, vn=vn_in_file, time_name=time_name, load=load).get_anom(ref_period=anom_period).wrap_lon(lon_name=lon_name, time_name=time_name)
                 elif time_name == 'year':
-                    self.__dict__[tag][vn] = ClimateField().load_nc(path, vn=vn_in_file, time_name=time_name).center(ref_period=anom_period, time_name=time_name).wrap_lon(lon_name=lon_name, time_name=time_name)
+                    self.__dict__[tag][vn] = ClimateField().load_nc(path, vn=vn_in_file, time_name=time_name, load=load).center(ref_period=anom_period, time_name=time_name).wrap_lon(lon_name=lon_name, time_name=time_name)
 
             self.__dict__[tag][vn].da.name = vn
 
@@ -303,7 +304,7 @@ class ReconJob:
             months (list): the list of months for annualization.
             verbose (bool, optional): print verbose information. Defaults to False.
         '''
-        months = self.io_cfg('prior_annualize_months', months, default=list(range(1, 13)), verbose=verbose)
+        months = self.io_cfg(f'{tag}_annualize_months', months, default=list(range(1, 13)), verbose=verbose)
 
         for vn, fd in self.__dict__[tag].items():
             if verbose: p_header(f'>>> Processing {vn} ...')
@@ -324,13 +325,13 @@ class ReconJob:
             periodic_lon (bool): if True, then assume the original longitudes form a loop.
         '''
         if lats is None and lons is None:
-            nlat = self.io_cfg('prior_regrid_nlat', nlat, default=42, verbose=verbose)
-            nlon = self.io_cfg('prior_regrid_nlon', nlon, default=63, verbose=verbose)
+            nlat = self.io_cfg(f'{tag}_regrid_nlat', nlat, default=42, verbose=verbose)
+            nlon = self.io_cfg(f'{tag}_regrid_nlon', nlon, default=63, verbose=verbose)
             lats = np.linspace(-90, 90, nlat)
             lons = np.linspace(0, 360, nlon)
         else:
-            lats = self.io_cfg('prior_regrid_lats', lats, verbose=verbose)
-            lons = self.io_cfg('prior_regrid_lons', lons, verbose=verbose)
+            lats = self.io_cfg(f'{tag}_regrid_lats', lats, verbose=verbose)
+            lons = self.io_cfg(f'{tag}_regrid_lons', lons, verbose=verbose)
 
         for vn, fd in self.__dict__[tag].items():
             if verbose: p_header(f'>>> Processing {vn} ...')
